==> aria2-1.8.0.tar.xz: aria2-1.8.0/src/XmlRpcResponse.h <==
/* <!-- copyright */
/*
 * aria2 - The high speed download utility
 *
 * Copyright (C) 2009 Tatsuhiro Tsujikawa
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 *
 * In addition, as a special exception, the copyright holders give
 * permission to link the code of portions of this program with the
 * OpenSSL library under certain conditions as described in each
 * individual source file, and distribute linked combinations
 * including the two.
 * You must obey the GNU General Public License in all respects
 * for all of the code used other than OpenSSL.  If you modify
 * file(s) with this exception, you may extend this exception to your
 * version of the file(s), but you are not obligated to do so.  If you
 * do not wish to do so, delete this exception statement from your
 * version.  If you delete this exception statement from all source
 * files in the program, then also delete it here.
 */
/* copyright --> */
#ifndef _D_XML_RPC_RESPONSE_H_
#define _D_XML_RPC_RESPONSE_H_

#include "common.h"

#include <string>

#include "BDE.h"

namespace aria2 {

namespace xmlrpc {

struct XmlRpcResponse {
  // 0 for success, non-zero for error
  int _code;
  
  BDE _param;

  XmlRpcResponse(int code, const BDE& param):_code(code), _param(param) {}

  std::string toXml() const;
};

} // namespace xmlrpc

} // namespace aria2

#endif // _D_XML_RPC_RESPONSE_H_

==> aria2-1.10.6.tar.xz: aria2-1.10.6/src/XmlRpcResponse.h <==
/* <!-- copyright */
/*
 * aria2 - The high speed download utility
 *
 * Copyright (C) 2009 Tatsuhiro Tsujikawa
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 *
 * In addition, as a special exception, the copyright holders give
 * permission to link the code of portions of this program with the
 * OpenSSL library under certain conditions as described in each
 * individual source file, and distribute linked combinations
 * including the two.
 * You must obey the GNU General Public License in all respects
 * for all of the code used other than OpenSSL.  If you modify
 * file(s) with this exception, you may extend this exception to your
 * version of the file(s), but you are not obligated to do so.  If you
 * do not wish to do so, delete this exception statement from your
 * version.  If you delete this exception statement from all source
 * files in the program, then also delete it here.
 */
/* copyright --> */
#ifndef D_XML_RPC_RESPONSE_H
#define D_XML_RPC_RESPONSE_H

#include "common.h"

#include <string>

#include "ValueBase.h"

namespace aria2 {

namespace xmlrpc {

struct XmlRpcResponse {
  // 0 for success, non-zero for error
  int code;
  
  SharedHandle<ValueBase> param;

  XmlRpcResponse
  (int code, const SharedHandle<ValueBase>& param):code(code), param(param) {}

  std::string toXml(bool gzip = false) const;
};

} // namespace xmlrpc

} // namespace aria2

#endif // D_XML_RPC_RESPONSE_H
